@@ -20,7 +20,7 @@ const WINDOW_HEIGHT: f32 = CARD_ROWS as f32 * (CARD_HEIGHT + CARD_MARGIN) + CARD
 
 fn main() -> Result<()> {
     unsafe {
-        CoInitializeEx(None, COINIT_MULTITHREADED)?;
+        CoInitializeEx(None, COINIT_MULTITHREADED).ok()?;
         SetProcessDpiAwarenessContext(DPI_AWARENESS_CONTEXT_PER_MONITOR_AWARE_V2)?;
     }
     let mut window = Window::new()?;
@@ -103,7 +103,7 @@ impl Window {
                 CoCreateInstance(&UIAnimationTransitionLibrary2, None, CLSCTX_INPROC_SERVER)?;
 
             Ok(Window {
-                handle: HWND(0),
+                handle: Default::default(),
                 dpi: (0.0, 0.0),
                 format: create_text_format()?,
                 image: create_image()?,
@@ -145,7 +145,7 @@ impl Window {
                 None,
             )?;
 
-            let bitmap = dc.CreateBitmapFromWicBitmap2(&self.image, None)?;
+            let bitmap = dc.CreateBitmapFromWicBitmap(&self.image, None)?;
             let width = logical_to_physical(CARD_WIDTH, self.dpi.0);
             let height = logical_to_physical(CARD_HEIGHT, self.dpi.1);
 
@@ -446,13 +446,13 @@ impl Window {
                 None,
                 instance,
                 Some(self as *mut _ as _),
-            );
+            )?;
 
-            debug_assert!(handle.0 != 0);
+            debug_assert!(!handle.is_invalid());
             debug_assert!(handle == self.handle);
             let mut message = MSG::default();
 
-            while GetMessageA(&mut message, HWND(0), 0, 0).into() {
+            while GetMessageA(&mut message, HWND::default(), 0, 0).into() {
                 DispatchMessageA(&message);
             }
 
@@ -732,13 +732,14 @@ fn draw_card_back(
             bitmap,
             None,
             1.0,
-            D2D1_BITMAP_INTERPOLATION_MODE_LINEAR,
+            D2D1_INTERPOLATION_MODE_LINEAR,
             Some(&D2D_RECT_F {
                 left,
                 top,
                 right: left + CARD_WIDTH,
                 bottom: top + CARD_HEIGHT,
             }),
+            None,
         );
 
         surface.EndDraw()
