@@ -9,7 +9,7 @@ use windows::{
 
 fn main() -> Result<()> {
     unsafe {
-        CoInitializeEx(None, COINIT_MULTITHREADED)?;
+        CoInitializeEx(None, COINIT_MULTITHREADED).ok()?;
     }
     let mut window = Window::new()?;
     window.run()
@@ -19,7 +19,7 @@ struct Window {
     handle: HWND,
     factory: ID2D1Factory1,
     dxfactory: IDXGIFactory2,
-    style: ID2D1StrokeStyle,
+    style: ID2D1StrokeStyle1,
     manager: IUIAnimationManager,
     variable: IUIAnimationVariable,
 
@@ -83,7 +83,7 @@ impl Window {
         };
 
         Ok(Window {
-            handle: HWND(0),
+            handle: Default::default(),
             factory,
             dxfactory,
             style,
@@ -125,7 +125,7 @@ impl Window {
             target.EndDraw(None, None)?;
         }
 
-        if let Err(error) = self.present(1, 0) {
+        if let Err(error) = self.present(1, DXGI_PRESENT(0)) {
             if error.code() == DXGI_STATUS_OCCLUDED {
                 self.occlusion = unsafe {
                     self.dxfactory
@@ -152,7 +152,7 @@ impl Window {
         self.shadow = None;
     }
 
-    fn present(&self, sync: u32, flags: u32) -> Result<()> {
+    fn present(&self, sync: u32, flags: DXGI_PRESENT) -> Result<()> {
         unsafe { self.swapchain.as_ref().unwrap().Present(sync, flags).ok() }
     }
 
@@ -310,7 +310,7 @@ impl Window {
             ..Default::default()
         };
 
-        unsafe { target.CreateBitmap2(size_u, None, 0, &properties) }
+        unsafe { target.CreateBitmap(size_u, None, 0, &properties) }
     }
 
     fn resize_swapchain_bitmap(&mut self) -> Result<()> {
@@ -320,7 +320,7 @@ impl Window {
 
             if unsafe {
                 swapchain
-                    .ResizeBuffers(0, 0, 0, DXGI_FORMAT_UNKNOWN, 0)
+                    .ResizeBuffers(0, 0, 0, DXGI_FORMAT_UNKNOWN, DXGI_SWAP_CHAIN_FLAG(0))
                     .is_ok()
             } {
                 create_swapchain_bitmap(swapchain, target)?;
@@ -342,7 +342,7 @@ impl Window {
                     let mut ps = PAINTSTRUCT::default();
                     BeginPaint(self.handle, &mut ps);
                     self.render().unwrap();
-                    EndPaint(self.handle, &ps);
+                    _ = EndPaint(self.handle, &ps);
                     LRESULT(0)
                 }
                 WM_SIZE => {
@@ -379,7 +379,6 @@ impl Window {
     fn run(&mut self) -> Result<()> {
         unsafe {
             let instance = GetModuleHandleA(None)?;
-            debug_assert!(instance.0 != 0);
             let window_class = s!("window");
 
             let wc = WNDCLASSA {
@@ -408,9 +407,9 @@ impl Window {
                 None,
                 instance,
                 Some(self as *mut _ as _),
-            );
+            )?;
 
-            debug_assert!(handle.0 != 0);
+            debug_assert!(!handle.is_invalid());
             debug_assert!(handle == self.handle);
             let mut message = MSG::default();
 
@@ -425,7 +424,7 @@ impl Window {
                         DispatchMessageA(&message);
                     }
                 } else {
-                    GetMessageA(&mut message, None, 0, 0);
+                    _ = GetMessageA(&mut message, None, 0, 0);
 
                     if message.message == WM_QUIT {
                         return Ok(());
@@ -506,8 +505,8 @@ fn create_factory() -> Result<ID2D1Factory1> {
     unsafe { D2D1CreateFactory(D2D1_FACTORY_TYPE_SINGLE_THREADED, Some(&options)) }
 }
 
-fn create_style(factory: &ID2D1Factory1) -> Result<ID2D1StrokeStyle> {
-    let props = D2D1_STROKE_STYLE_PROPERTIES {
+fn create_style(factory: &ID2D1Factory1) -> Result<ID2D1StrokeStyle1> {
+    let props = D2D1_STROKE_STYLE_PROPERTIES1 {
         startCap: D2D1_CAP_STYLE_ROUND,
         endCap: D2D1_CAP_STYLE_TRIANGLE,
         ..Default::default()
