@@ -100,17 +100,17 @@ where
             instance,
             Some(&mut sample as *mut _ as _),
         )
-    };
+    }?;
 
     sample.bind_to_window(&hwnd)?;
-    unsafe { ShowWindow(hwnd, SW_SHOW) };
+    unsafe { _ = ShowWindow(hwnd, SW_SHOW) };
 
     loop {
         let mut message = MSG::default();
 
         if unsafe { PeekMessageA(&mut message, None, 0, 0, PM_REMOVE) }.into() {
             unsafe {
-                TranslateMessage(&message);
+                _ = TranslateMessage(&message);
                 DispatchMessageA(&message);
             }
 
@@ -179,11 +179,9 @@ extern "system" fn wndproc<S: DXSample>(
 fn get_hardware_adapter(factory: &IDXGIFactory4) -> Result<IDXGIAdapter1> {
     for i in 0.. {
         let adapter = unsafe { factory.EnumAdapters1(i)? };
+        let desc = unsafe { adapter.GetDesc1()? };
 
-        let mut desc = Default::default();
-        unsafe { adapter.GetDesc1(&mut desc)? };
-
-        if (DXGI_ADAPTER_FLAG(desc.Flags as i32) & DXGI_ADAPTER_FLAG_SOFTWARE)
+        if (DXGI_ADAPTER_FLAG(desc.Flags as _) & DXGI_ADAPTER_FLAG_SOFTWARE)
             != DXGI_ADAPTER_FLAG_NONE
         {
             // Don't select the Basic Render Driver adapter. If you want a
@@ -411,11 +409,13 @@ mod d3d12_hello_triangle {
                 populate_command_list(resources).unwrap();
 
                 // Execute the command list.
-                let command_list = Some(resources.command_list.can_clone_into());
+                let command_list = Some(resources.command_list.cast().unwrap());
                 unsafe { resources.command_queue.ExecuteCommandLists(&[command_list]) };
 
                 // Present the frame.
-                unsafe { resources.swap_chain.Present(1, 0) }.ok().unwrap();
+                unsafe { resources.swap_chain.Present(1, DXGI_PRESENT(0)) }
+                    .ok()
+                    .unwrap();
 
                 wait_for_previous_frame(resources);
             }
@@ -515,7 +515,7 @@ mod d3d12_hello_triangle {
         let dxgi_factory_flags = if cfg!(debug_assertions) {
             DXGI_CREATE_FACTORY_DEBUG
         } else {
-            0
+            DXGI_CREATE_FACTORY_FLAGS(0)
         };
 
         let dxgi_factory: IDXGIFactory4 = unsafe { CreateDXGIFactory2(dxgi_factory_flags) }?;
@@ -669,7 +669,7 @@ mod d3d12_hello_triangle {
                 ],
             },
             DepthStencilState: D3D12_DEPTH_STENCIL_DESC::default(),
-            SampleMask: u32::max_value(),
+            SampleMask: u32::MAX,
             PrimitiveTopologyType: D3D12_PRIMITIVE_TOPOLOGY_TYPE_TRIANGLE,
             NumRenderTargets: 1,
             SampleDesc: DXGI_SAMPLE_DESC {
