@@ -7,13 +7,13 @@ use windows::Win32::System::Com::*;
 #[implement(IPersistStream)]
 struct Test();
 
-impl IPersist_Impl for Test {
+impl IPersist_Impl for Test_Impl {
     fn GetClassID(&self) -> Result<GUID> {
         Ok(GUID::zeroed())
     }
 }
 
-impl IPersistStream_Impl for Test {
+impl IPersistStream_Impl for Test_Impl {
     fn IsDirty(&self) -> HRESULT {
         S_OK
     }
@@ -40,7 +40,7 @@ fn test() -> Result<()> {
         stream.cast::<IPersistStream>()?;
         stream.cast::<IPersist>()?;
 
-        let persist: &IPersist = stream.can_into();
+        let persist: &IPersist = &stream.cast()?;
         persist.GetClassID()?;
         persist.cast::<IPersistStream>()?;
         persist.cast::<IPersist>()?;
