@@ -3,9 +3,9 @@ use windows::{core::*, Foundation::*, Win32::Foundation::*};
 #[implement(IStringable)]
 struct Test;
 
-impl IStringable_Impl for Test {
+impl IStringable_Impl for Test_Impl {
     fn ToString(&self) -> Result<HSTRING> {
-        Err(Error::new(E_INVALIDARG, "Test message".into()))
+        Err(Error::new(E_INVALIDARG, "Test message"))
     }
 }
 
