@@ -1,20 +1,17 @@
 #![allow(non_snake_case)]
 
-use windows::{
-    core::*, Win32::System::Com::StructuredStorage::*, Win32::System::Com::*,
-    Win32::UI::Shell::PropertiesSystem::*,
-};
+use windows::{core::*, Win32::System::Com::*, Win32::UI::Shell::PropertiesSystem::*};
 
 #[implement(IInitializeWithStream, IPropertyStore, IPropertyStoreCapabilities)]
-struct Object();
+struct Object(std::sync::RwLock<PROPVARIANT>);
 
-impl IInitializeWithStream_Impl for Object {
+impl IInitializeWithStream_Impl for Object_Impl {
     fn Initialize(&self, _: Option<&IStream>, _: u32) -> Result<()> {
         Ok(())
     }
 }
 
-impl IPropertyStore_Impl for Object {
+impl IPropertyStore_Impl for Object_Impl {
     fn GetCount(&self) -> Result<u32> {
         Ok(123)
     }
@@ -22,17 +19,20 @@ impl IPropertyStore_Impl for Object {
         unimplemented!()
     }
     fn GetValue(&self, _: *const PROPERTYKEY) -> Result<PROPVARIANT> {
-        unimplemented!()
+        let reader = self.0.read().unwrap();
+        Ok(reader.clone())
     }
-    fn SetValue(&self, _: *const PROPERTYKEY, _: *const PROPVARIANT) -> Result<()> {
-        unimplemented!()
+    fn SetValue(&self, _: *const PROPERTYKEY, value: *const PROPVARIANT) -> Result<()> {
+        let mut writer = self.0.write().unwrap();
+        *writer = unsafe { (*value).clone() };
+        Ok(())
     }
     fn Commit(&self) -> Result<()> {
         unimplemented!()
     }
 }
 
-impl IPropertyStoreCapabilities_Impl for Object {
+impl IPropertyStoreCapabilities_Impl for Object_Impl {
     fn IsPropertyWritable(&self, _: *const PROPERTYKEY) -> Result<()> {
         Ok(())
     }
@@ -41,12 +41,15 @@ impl IPropertyStoreCapabilities_Impl for Object {
 #[test]
 fn test() -> Result<()> {
     unsafe {
-        let a: IInitializeWithStream = Object().into();
+        let a: IInitializeWithStream = Object(std::sync::RwLock::new(Default::default())).into();
         a.Initialize(None, 0)?;
 
         let b: IPropertyStore = a.cast()?;
         assert!(b.GetCount()? == 123);
 
+        b.SetValue(std::ptr::null(), &PROPVARIANT::from(123))?;
+        assert_eq!(PROPVARIANT::from(123), b.GetValue(std::ptr::null())?);
+
         let c: IPropertyStoreCapabilities = b.cast()?;
         c.IsPropertyWritable(&PROPERTYKEY::default())?;
 
