@@ -1,5 +1,5 @@
 use windows::{
-    core::{ComInterface, Result, HSTRING},
+    core::{Interface, Result, HSTRING},
     Foundation::Collections::StringMap,
     Win32::System::Com::{CoInitializeEx, COINIT_MULTITHREADED},
     Win32::System::WinRT::RoActivateInstance,
@@ -11,7 +11,7 @@ use windows::{
 // activate WinRT types directly as it can do so far more efficiently.
 #[test]
 fn test() -> Result<()> {
-    unsafe { CoInitializeEx(None, COINIT_MULTITHREADED)? };
+    unsafe { CoInitializeEx(None, COINIT_MULTITHREADED).ok()? };
 
     let instance: HSTRING = "Windows.Foundation.Collections.StringMap".into();
     let instance = unsafe { RoActivateInstance(&instance)? };
