@@ -6,13 +6,13 @@
 #[windows::core::implement(windows::Foundation::{IStringable, IClosable})]
 struct Test(&'static str);
 
-impl windows::Foundation::IStringable_Impl for Test {
+impl windows::Foundation::IStringable_Impl for Test_Impl {
     fn ToString(&self) -> windows::core::Result<windows::core::HSTRING> {
         Ok(self.0.into())
     }
 }
 
-impl windows::Foundation::IClosable_Impl for Test {
+impl windows::Foundation::IClosable_Impl for Test_Impl {
     fn Close(&self) -> windows::core::Result<()> {
         Ok(())
     }
@@ -23,7 +23,7 @@ fn test() -> windows::core::Result<()> {
     let a: windows::Foundation::IStringable = Test("test").into();
     assert!(a.ToString()? == "test");
 
-    let b: windows::Foundation::IClosable = windows::core::ComInterface::cast(&a)?;
+    let b: windows::Foundation::IClosable = windows::core::Interface::cast(&a)?;
     b.Close()?;
 
     Ok(())
