@@ -5,6 +5,6 @@ use windows_sys::Win32::Graphics::Printing::*;
 #[test]
 fn test() {
     unsafe {
-        GetSpoolFileHandle(0);
+        GetSpoolFileHandle(core::ptr::null_mut());
     }
 }
