@@ -8,25 +8,17 @@ use windows::{
 fn test() -> Result<()> {
     unsafe {
         assert_eq!(InSendMessageEx(None), ISMEX_NOSEND);
-        assert!(CreateThreadpool(None).0 != 0);
+        assert!(CreateThreadpool(None).is_ok());
 
         assert_eq!(
-            TrackPopupMenu(
-                HMENU(0),
-                TPM_LEFTBUTTON,
-                1,
-                2,
-                0,
-                HWND(0),
-                Default::default(),
-            ),
+            TrackPopupMenu(None, TPM_LEFTBUTTON, 1, 2, 0, None, Default::default(),),
             FALSE
         );
 
         let mut key = HKEY::default();
-        RegOpenKeyExA(HKEY_CLASSES_ROOT, s!(r".txt"), 0, KEY_QUERY_VALUE, &mut key)?;
+        RegOpenKeyExA(HKEY_CLASSES_ROOT, s!(r".txt"), 0, KEY_QUERY_VALUE, &mut key).ok()?;
         let mut len = 0;
-        RegQueryValueExA(key, s!("Content Type"), None, None, None, Some(&mut len))?;
+        RegQueryValueExA(key, s!("Content Type"), None, None, None, Some(&mut len)).ok()?;
         let mut buffer = vec![0u8; (len) as usize];
         RegQueryValueExA(
             key,
@@ -35,7 +27,8 @@ fn test() -> Result<()> {
             None,
             Some(buffer.as_mut_ptr() as _),
             Some(&mut len),
-        )?;
+        )
+        .ok()?;
         assert_eq!(String::from_utf8_lossy(&buffer), "text/plain\0");
         Ok(())
     }
