@@ -26,20 +26,20 @@ fn types() {
     let _: i32 = DBG_APP_NOT_IDLE;
 
     // Handles
-    let _: HANDLE = 0;
+    let _: HANDLE = core::ptr::null_mut();
     let _: PSTR = b"hello\0".as_ptr() as _;
 }
 
 #[test]
 fn callback() {
     unsafe {
-        extern "system" fn enum_window(_: isize, _: isize) -> i32 {
+        extern "system" fn enum_window(_: *mut core::ffi::c_void, _: isize) -> i32 {
             0
         }
 
         EnumWindows(Some(enum_window), 0);
 
-        extern "system" fn wndproc(_: isize, _: u32, _: usize, _: isize) -> isize {
+        extern "system" fn wndproc(_: *mut core::ffi::c_void, _: u32, _: usize, _: isize) -> isize {
             0
         }
 
