@@ -4,8 +4,8 @@ use windows::{core::*, Wdk::System::OfflineRegistry::*};
 fn test() -> Result<()> {
     unsafe {
         let mut hive = ORHKEY::default();
-        ORCreateHive(&mut hive)?;
-        ORCloseHive(hive)?;
+        ORCreateHive(&mut hive).ok()?;
+        ORCloseHive(hive).ok()?;
         Ok(())
     }
 }
