@@ -1,10 +1,9 @@
-use std::convert::TryInto;
 use windows::core::HRESULT;
 use windows::Win32::Foundation::*;
 
 #[test]
 fn test_message() {
-    assert!(helpers::set_thread_ui_language());
+    helpers::set_thread_ui_language();
 
     let code: HRESULT = ERROR_SUCCESS.into();
     let message: String = code.message().try_into().unwrap();
