@@ -78,103 +78,6 @@ namespace winrt::impl
     {
         return ((int32_t)((x) | 0x10000000));
     }
-
-    struct error_info_fallback final : IErrorInfo, IRestrictedErrorInfo, update_module_lock
-    {
-        error_info_fallback(int32_t code, void* message) noexcept :
-            m_code(code),
-            m_message(message ? *reinterpret_cast<winrt::hstring*>(&message) : message_from_hresult(code))
-        {
-        }
-
-        int32_t __stdcall QueryInterface(guid const& id, void** object) noexcept final
-        {
-            if (is_guid_of<IRestrictedErrorInfo>(id) || is_guid_of<Windows::Foundation::IUnknown>(id) || is_guid_of<IAgileObject>(id))
-            {
-                *object = static_cast<IRestrictedErrorInfo*>(this);
-                AddRef();
-                return 0;
-            }
-
-            if (is_guid_of<IErrorInfo>(id))
-            {
-                *object = static_cast<IErrorInfo*>(this);
-                AddRef();
-                return 0;
-            }
-
-            *object = nullptr;
-            return error_no_interface;
-        }
-
-        uint32_t __stdcall AddRef() noexcept final
-        {
-            return ++m_references;
-        }
-
-        uint32_t __stdcall Release() noexcept final
-        {
-            auto const remaining = --m_references;
-
-            if (remaining == 0)
-            {
-                delete this;
-            }
-
-            return remaining;
-        }
-
-        int32_t __stdcall GetGUID(guid* value) noexcept final
-        {
-            *value = {};
-            return 0;
-        }
-
-        int32_t __stdcall GetSource(bstr* value) noexcept final
-        {
-            *value = nullptr;
-            return 0;
-        }
-
-        int32_t __stdcall GetDescription(bstr* value) noexcept final
-        {
-            *value = WINRT_IMPL_SysAllocString(m_message.c_str());
-            return *value ? error_ok : error_bad_alloc;
-        }
-
-        int32_t __stdcall GetHelpFile(bstr* value) noexcept final
-        {
-            *value = nullptr;
-            return 0;
-        }
-
-        int32_t __stdcall GetHelpContext(uint32_t* value) noexcept final
-        {
-            *value = 0;
-            return 0;
-        }
-
-        int32_t __stdcall GetErrorDetails(bstr* fallback, int32_t* error, bstr* message, bstr* capability) noexcept final
-        {
-            *fallback = nullptr;
-            *error = m_code;
-            *capability = nullptr;
-            *message = WINRT_IMPL_SysAllocString(m_message.c_str());
-            return *message ? error_ok : error_bad_alloc;
-        }
-
-        int32_t __stdcall GetReference(bstr* value) noexcept final
-        {
-            *value = nullptr;
-            return 0;
-        }
-
-    private:
-
-        hresult const m_code;
-        hstring const m_message;
-        atomic_ref_count m_references{ 1 };
-    };
 }
 
 WINRT_EXPORT namespace winrt
@@ -313,8 +216,8 @@ WINRT_EXPORT namespace winrt
             }
 
             com_ptr<impl::IErrorInfo> info;
-            WINRT_VERIFY_(0, WINRT_IMPL_GetErrorInfo(0, info.put_void()));
-            WINRT_VERIFY(info.try_as(m_info));
+            WINRT_IMPL_GetErrorInfo(0, info.put_void());
+            info.try_as(m_info);
         }
 
         static hresult verify_error(hresult const code) noexcept
